selenium_wrapper_web_driver_not_found_error = "WebDriver not found"

selenium_wrapper_set_options_error = "options must be a dict"
selenium_wrapper_set_argument_error = "argument must be a string"

executor_data_error = "executor received invalid data"
executor_list_error = "executor received invalid data: list is empty or of wrong type"

# json
cant_find_json_error = "can't find JSON file"
cant_save_json_error = "can't save JSON file"
cant_reformat_json_error = "can't reformat JSON: is the type correct?"
cant_find_element_in_json_error = "can't find element in JSON"
json_type_error = "JSON type error"
wrong_json_data_error = "can't parse JSON"
cant_generate_json_report: str = "can't generate JSON report"

html_generate_no_data_tag = "can't generate HTML report: data is null"

# add command
add_command_exception_tag = "command value type must be a method or function"

# argparse
argparse_get_wrong_data = "argparse received invalid data"

# XML
cant_read_xml_error: str = "can't read XML"
xml_type_error = "XML type error"

# Callback executor
get_bad_trigger_method: str = "invalid trigger method: only kwargs and args accepted"
get_bad_trigger_function: str = "invalid trigger function: only functions in event_dict accepted"